# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetAuthenticatorResult',
    'AwaitableGetAuthenticatorResult',
    'get_authenticator',
    'get_authenticator_output',
]

@pulumi.output_type
class GetAuthenticatorResult:
    """
    A collection of values returned by getAuthenticator.
    """
    def __init__(__self__, id=None, key=None, name=None, provider_auth_port=None, provider_hostname=None, provider_instance_id=None, provider_json=None, provider_type=None, provider_user_name_template=None, settings=None, status=None, type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if key and not isinstance(key, str):
            raise TypeError("Expected argument 'key' to be a str")
        pulumi.set(__self__, "key", key)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if provider_auth_port and not isinstance(provider_auth_port, int):
            raise TypeError("Expected argument 'provider_auth_port' to be a int")
        pulumi.set(__self__, "provider_auth_port", provider_auth_port)
        if provider_hostname and not isinstance(provider_hostname, str):
            raise TypeError("Expected argument 'provider_hostname' to be a str")
        pulumi.set(__self__, "provider_hostname", provider_hostname)
        if provider_instance_id and not isinstance(provider_instance_id, str):
            raise TypeError("Expected argument 'provider_instance_id' to be a str")
        pulumi.set(__self__, "provider_instance_id", provider_instance_id)
        if provider_json and not isinstance(provider_json, str):
            raise TypeError("Expected argument 'provider_json' to be a str")
        pulumi.set(__self__, "provider_json", provider_json)
        if provider_type and not isinstance(provider_type, str):
            raise TypeError("Expected argument 'provider_type' to be a str")
        pulumi.set(__self__, "provider_type", provider_type)
        if provider_user_name_template and not isinstance(provider_user_name_template, str):
            raise TypeError("Expected argument 'provider_user_name_template' to be a str")
        pulumi.set(__self__, "provider_user_name_template", provider_user_name_template)
        if settings and not isinstance(settings, str):
            raise TypeError("Expected argument 'settings' to be a str")
        pulumi.set(__self__, "settings", settings)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def id(self) -> Optional[_builtins.str]:
        """
        ID of the authenticator.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[_builtins.str]:
        """
        A human-readable string that identifies the authenticator.
        """
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the authenticator.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="providerAuthPort")
    def provider_auth_port(self) -> _builtins.int:
        """
        The RADIUS server port (for example 1812). This is defined when the On-Prem RADIUS server is configured
        """
        return pulumi.get(self, "provider_auth_port")

    @_builtins.property
    @pulumi.getter(name="providerHostname")
    def provider_hostname(self) -> _builtins.str:
        """
        Server host name or IP address
        """
        return pulumi.get(self, "provider_hostname")

    @_builtins.property
    @pulumi.getter(name="providerInstanceId")
    def provider_instance_id(self) -> _builtins.str:
        """
        (Specific to `security_key`) App Instance ID.
        """
        return pulumi.get(self, "provider_instance_id")

    @_builtins.property
    @pulumi.getter(name="providerJson")
    def provider_json(self) -> _builtins.str:
        """
        Authenticator Provider in JSON format
        """
        return pulumi.get(self, "provider_json")

    @_builtins.property
    @pulumi.getter(name="providerType")
    def provider_type(self) -> _builtins.str:
        """
        Provider type.
        """
        return pulumi.get(self, "provider_type")

    @_builtins.property
    @pulumi.getter(name="providerUserNameTemplate")
    def provider_user_name_template(self) -> _builtins.str:
        """
        Username template expected by the provider.
        """
        return pulumi.get(self, "provider_user_name_template")

    @_builtins.property
    @pulumi.getter
    def settings(self) -> _builtins.str:
        """
        Authenticator settings in JSON format
        """
        return pulumi.get(self, "settings")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Status of the Authenticator.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Type of the authenticator
        """
        return pulumi.get(self, "type")


class AwaitableGetAuthenticatorResult(GetAuthenticatorResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAuthenticatorResult(
            id=self.id,
            key=self.key,
            name=self.name,
            provider_auth_port=self.provider_auth_port,
            provider_hostname=self.provider_hostname,
            provider_instance_id=self.provider_instance_id,
            provider_json=self.provider_json,
            provider_type=self.provider_type,
            provider_user_name_template=self.provider_user_name_template,
            settings=self.settings,
            status=self.status,
            type=self.type)


def get_authenticator(id: Optional[_builtins.str] = None,
                      key: Optional[_builtins.str] = None,
                      name: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAuthenticatorResult:
    """
    Get an authenticator by key, name of ID.

    > **WARNING:** This feature is only available as a part of the
    Identity Engine. Contact support
    for further information.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_authenticator(key="security_question")
    test1 = okta.get_authenticator(name="Okta Verify")
    ```


    :param _builtins.str id: ID of the authenticator.
    :param _builtins.str key: A human-readable string that identifies the authenticator.
    :param _builtins.str name: Name of the authenticator.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['key'] = key
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getAuthenticator:getAuthenticator', __args__, opts=opts, typ=GetAuthenticatorResult).value

    return AwaitableGetAuthenticatorResult(
        id=pulumi.get(__ret__, 'id'),
        key=pulumi.get(__ret__, 'key'),
        name=pulumi.get(__ret__, 'name'),
        provider_auth_port=pulumi.get(__ret__, 'provider_auth_port'),
        provider_hostname=pulumi.get(__ret__, 'provider_hostname'),
        provider_instance_id=pulumi.get(__ret__, 'provider_instance_id'),
        provider_json=pulumi.get(__ret__, 'provider_json'),
        provider_type=pulumi.get(__ret__, 'provider_type'),
        provider_user_name_template=pulumi.get(__ret__, 'provider_user_name_template'),
        settings=pulumi.get(__ret__, 'settings'),
        status=pulumi.get(__ret__, 'status'),
        type=pulumi.get(__ret__, 'type'))
def get_authenticator_output(id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             key: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAuthenticatorResult]:
    """
    Get an authenticator by key, name of ID.

    > **WARNING:** This feature is only available as a part of the
    Identity Engine. Contact support
    for further information.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_authenticator(key="security_question")
    test1 = okta.get_authenticator(name="Okta Verify")
    ```


    :param _builtins.str id: ID of the authenticator.
    :param _builtins.str key: A human-readable string that identifies the authenticator.
    :param _builtins.str name: Name of the authenticator.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['key'] = key
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getAuthenticator:getAuthenticator', __args__, opts=opts, typ=GetAuthenticatorResult)
    return __ret__.apply(lambda __response__: GetAuthenticatorResult(
        id=pulumi.get(__response__, 'id'),
        key=pulumi.get(__response__, 'key'),
        name=pulumi.get(__response__, 'name'),
        provider_auth_port=pulumi.get(__response__, 'provider_auth_port'),
        provider_hostname=pulumi.get(__response__, 'provider_hostname'),
        provider_instance_id=pulumi.get(__response__, 'provider_instance_id'),
        provider_json=pulumi.get(__response__, 'provider_json'),
        provider_type=pulumi.get(__response__, 'provider_type'),
        provider_user_name_template=pulumi.get(__response__, 'provider_user_name_template'),
        settings=pulumi.get(__response__, 'settings'),
        status=pulumi.get(__response__, 'status'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetReviewResult',
    'AwaitableGetReviewResult',
    'get_review',
    'get_review_output',
]

@pulumi.output_type
class GetReviewResult:
    """
    A collection of values returned by getReview.
    """
    def __init__(__self__, all_reviewer_levels=None, campaign_id=None, created=None, created_by=None, current_reviewer_level=None, decided=None, decision=None, entitlement_bundle=None, entitlement_value=None, id=None, last_updated=None, last_updated_by=None, links=None, note=None, principal_profile=None, remediation_status=None, resource_id=None, reviewer_profile=None, reviewer_type=None):
        if all_reviewer_levels and not isinstance(all_reviewer_levels, list):
            raise TypeError("Expected argument 'all_reviewer_levels' to be a list")
        pulumi.set(__self__, "all_reviewer_levels", all_reviewer_levels)
        if campaign_id and not isinstance(campaign_id, str):
            raise TypeError("Expected argument 'campaign_id' to be a str")
        pulumi.set(__self__, "campaign_id", campaign_id)
        if created and not isinstance(created, str):
            raise TypeError("Expected argument 'created' to be a str")
        pulumi.set(__self__, "created", created)
        if created_by and not isinstance(created_by, str):
            raise TypeError("Expected argument 'created_by' to be a str")
        pulumi.set(__self__, "created_by", created_by)
        if current_reviewer_level and not isinstance(current_reviewer_level, str):
            raise TypeError("Expected argument 'current_reviewer_level' to be a str")
        pulumi.set(__self__, "current_reviewer_level", current_reviewer_level)
        if decided and not isinstance(decided, str):
            raise TypeError("Expected argument 'decided' to be a str")
        pulumi.set(__self__, "decided", decided)
        if decision and not isinstance(decision, str):
            raise TypeError("Expected argument 'decision' to be a str")
        pulumi.set(__self__, "decision", decision)
        if entitlement_bundle and not isinstance(entitlement_bundle, dict):
            raise TypeError("Expected argument 'entitlement_bundle' to be a dict")
        pulumi.set(__self__, "entitlement_bundle", entitlement_bundle)
        if entitlement_value and not isinstance(entitlement_value, dict):
            raise TypeError("Expected argument 'entitlement_value' to be a dict")
        pulumi.set(__self__, "entitlement_value", entitlement_value)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if last_updated and not isinstance(last_updated, str):
            raise TypeError("Expected argument 'last_updated' to be a str")
        pulumi.set(__self__, "last_updated", last_updated)
        if last_updated_by and not isinstance(last_updated_by, str):
            raise TypeError("Expected argument 'last_updated_by' to be a str")
        pulumi.set(__self__, "last_updated_by", last_updated_by)
        if links and not isinstance(links, dict):
            raise TypeError("Expected argument 'links' to be a dict")
        pulumi.set(__self__, "links", links)
        if note and not isinstance(note, dict):
            raise TypeError("Expected argument 'note' to be a dict")
        pulumi.set(__self__, "note", note)
        if principal_profile and not isinstance(principal_profile, dict):
            raise TypeError("Expected argument 'principal_profile' to be a dict")
        pulumi.set(__self__, "principal_profile", principal_profile)
        if remediation_status and not isinstance(remediation_status, str):
            raise TypeError("Expected argument 'remediation_status' to be a str")
        pulumi.set(__self__, "remediation_status", remediation_status)
        if resource_id and not isinstance(resource_id, str):
            raise TypeError("Expected argument 'resource_id' to be a str")
        pulumi.set(__self__, "resource_id", resource_id)
        if reviewer_profile and not isinstance(reviewer_profile, dict):
            raise TypeError("Expected argument 'reviewer_profile' to be a dict")
        pulumi.set(__self__, "reviewer_profile", reviewer_profile)
        if reviewer_type and not isinstance(reviewer_type, str):
            raise TypeError("Expected argument 'reviewer_type' to be a str")
        pulumi.set(__self__, "reviewer_type", reviewer_type)

    @_builtins.property
    @pulumi.getter(name="allReviewerLevels")
    def all_reviewer_levels(self) -> Optional[Sequence['outputs.GetReviewAllReviewerLevelResult']]:
        return pulumi.get(self, "all_reviewer_levels")

    @_builtins.property
    @pulumi.getter(name="campaignId")
    def campaign_id(self) -> _builtins.str:
        """
        ID of the Campaign.
        """
        return pulumi.get(self, "campaign_id")

    @_builtins.property
    @pulumi.getter
    def created(self) -> _builtins.str:
        """
        The ISO 8601 formatted date and time when the resource was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> _builtins.str:
        """
        The id of user who created the resource.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter(name="currentReviewerLevel")
    def current_reviewer_level(self) -> _builtins.str:
        """
        Identifies the reviewer level of each reviews during access certification.
        """
        return pulumi.get(self, "current_reviewer_level")

    @_builtins.property
    @pulumi.getter
    def decided(self) -> _builtins.str:
        """
        The ISO 8601 formatted date and time when the object status was decided.
        """
        return pulumi.get(self, "decided")

    @_builtins.property
    @pulumi.getter
    def decision(self) -> _builtins.str:
        """
        The decision taken by the reviewer. Will be `UNASSIGNED` if no decision is made.
        """
        return pulumi.get(self, "decision")

    @_builtins.property
    @pulumi.getter(name="entitlementBundle")
    def entitlement_bundle(self) -> Optional['outputs.GetReviewEntitlementBundleResult']:
        return pulumi.get(self, "entitlement_bundle")

    @_builtins.property
    @pulumi.getter(name="entitlementValue")
    def entitlement_value(self) -> Optional['outputs.GetReviewEntitlementValueResult']:
        return pulumi.get(self, "entitlement_value")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The ID of  review.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="lastUpdated")
    def last_updated(self) -> _builtins.str:
        """
        The ISO 8601 formatted date and time when the object was last updated.
        """
        return pulumi.get(self, "last_updated")

    @_builtins.property
    @pulumi.getter(name="lastUpdatedBy")
    def last_updated_by(self) -> _builtins.str:
        """
        The id of user who last updated the object.
        """
        return pulumi.get(self, "last_updated_by")

    @_builtins.property
    @pulumi.getter
    def links(self) -> Optional['outputs.GetReviewLinksResult']:
        return pulumi.get(self, "links")

    @_builtins.property
    @pulumi.getter
    def note(self) -> Optional['outputs.GetReviewNoteResult']:
        return pulumi.get(self, "note")

    @_builtins.property
    @pulumi.getter(name="principalProfile")
    def principal_profile(self) -> Optional['outputs.GetReviewPrincipalProfileResult']:
        """
        A limited set of properties from the user profile who created the review.
        """
        return pulumi.get(self, "principal_profile")

    @_builtins.property
    @pulumi.getter(name="remediationStatus")
    def remediation_status(self) -> _builtins.str:
        """
        Enum: `ERROR`, `MANUAL`, `NONE`, `OPEN`, `SUCCESS`.
        """
        return pulumi.get(self, "remediation_status")

    @_builtins.property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> _builtins.str:
        """
        Resource ID for the Review.
        """
        return pulumi.get(self, "resource_id")

    @_builtins.property
    @pulumi.getter(name="reviewerProfile")
    def reviewer_profile(self) -> Optional['outputs.GetReviewReviewerProfileResult']:
        return pulumi.get(self, "reviewer_profile")

    @_builtins.property
    @pulumi.getter(name="reviewerType")
    def reviewer_type(self) -> _builtins.str:
        """
        The type of reviewer to which the review is assigned.
        """
        return pulumi.get(self, "reviewer_type")


class AwaitableGetReviewResult(GetReviewResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetReviewResult(
            all_reviewer_levels=self.all_reviewer_levels,
            campaign_id=self.campaign_id,
            created=self.created,
            created_by=self.created_by,
            current_reviewer_level=self.current_reviewer_level,
            decided=self.decided,
            decision=self.decision,
            entitlement_bundle=self.entitlement_bundle,
            entitlement_value=self.entitlement_value,
            id=self.id,
            last_updated=self.last_updated,
            last_updated_by=self.last_updated_by,
            links=self.links,
            note=self.note,
            principal_profile=self.principal_profile,
            remediation_status=self.remediation_status,
            resource_id=self.resource_id,
            reviewer_profile=self.reviewer_profile,
            reviewer_type=self.reviewer_type)


def get_review(all_reviewer_levels: Optional[Sequence[Union['GetReviewAllReviewerLevelArgs', 'GetReviewAllReviewerLevelArgsDict']]] = None,
               entitlement_bundle: Optional[Union['GetReviewEntitlementBundleArgs', 'GetReviewEntitlementBundleArgsDict']] = None,
               entitlement_value: Optional[Union['GetReviewEntitlementValueArgs', 'GetReviewEntitlementValueArgsDict']] = None,
               id: Optional[_builtins.str] = None,
               links: Optional[Union['GetReviewLinksArgs', 'GetReviewLinksArgsDict']] = None,
               note: Optional[Union['GetReviewNoteArgs', 'GetReviewNoteArgsDict']] = None,
               principal_profile: Optional[Union['GetReviewPrincipalProfileArgs', 'GetReviewPrincipalProfileArgsDict']] = None,
               reviewer_profile: Optional[Union['GetReviewReviewerProfileArgs', 'GetReviewReviewerProfileArgsDict']] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetReviewResult:
    """
    Get the reviews belonging to a campaign

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_review()
    ```

    ## Required:

    - `email` (String) The Okta user's email address.
    - `id` (String) The Okta user id.
    - `status` (String) The status of the principal's profile. Enum: `INACTIVE`, `ACTIVE`.

    ## Optional:

    - `first_name` (String) The Okta user's first name.
    - `lastName` (String) The Okta user's last name
    - `login` (String) The Okta user's login


    :param _builtins.str id: The ID of  review.
    :param Union['GetReviewPrincipalProfileArgs', 'GetReviewPrincipalProfileArgsDict'] principal_profile: A limited set of properties from the user profile who created the review.
    """
    __args__ = dict()
    __args__['allReviewerLevels'] = all_reviewer_levels
    __args__['entitlementBundle'] = entitlement_bundle
    __args__['entitlementValue'] = entitlement_value
    __args__['id'] = id
    __args__['links'] = links
    __args__['note'] = note
    __args__['principalProfile'] = principal_profile
    __args__['reviewerProfile'] = reviewer_profile
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getReview:getReview', __args__, opts=opts, typ=GetReviewResult).value

    return AwaitableGetReviewResult(
        all_reviewer_levels=pulumi.get(__ret__, 'all_reviewer_levels'),
        campaign_id=pulumi.get(__ret__, 'campaign_id'),
        created=pulumi.get(__ret__, 'created'),
        created_by=pulumi.get(__ret__, 'created_by'),
        current_reviewer_level=pulumi.get(__ret__, 'current_reviewer_level'),
        decided=pulumi.get(__ret__, 'decided'),
        decision=pulumi.get(__ret__, 'decision'),
        entitlement_bundle=pulumi.get(__ret__, 'entitlement_bundle'),
        entitlement_value=pulumi.get(__ret__, 'entitlement_value'),
        id=pulumi.get(__ret__, 'id'),
        last_updated=pulumi.get(__ret__, 'last_updated'),
        last_updated_by=pulumi.get(__ret__, 'last_updated_by'),
        links=pulumi.get(__ret__, 'links'),
        note=pulumi.get(__ret__, 'note'),
        principal_profile=pulumi.get(__ret__, 'principal_profile'),
        remediation_status=pulumi.get(__ret__, 'remediation_status'),
        resource_id=pulumi.get(__ret__, 'resource_id'),
        reviewer_profile=pulumi.get(__ret__, 'reviewer_profile'),
        reviewer_type=pulumi.get(__ret__, 'reviewer_type'))
def get_review_output(all_reviewer_levels: Optional[pulumi.Input[Optional[Sequence[Union['GetReviewAllReviewerLevelArgs', 'GetReviewAllReviewerLevelArgsDict']]]]] = None,
                      entitlement_bundle: Optional[pulumi.Input[Optional[Union['GetReviewEntitlementBundleArgs', 'GetReviewEntitlementBundleArgsDict']]]] = None,
                      entitlement_value: Optional[pulumi.Input[Optional[Union['GetReviewEntitlementValueArgs', 'GetReviewEntitlementValueArgsDict']]]] = None,
                      id: Optional[pulumi.Input[_builtins.str]] = None,
                      links: Optional[pulumi.Input[Optional[Union['GetReviewLinksArgs', 'GetReviewLinksArgsDict']]]] = None,
                      note: Optional[pulumi.Input[Optional[Union['GetReviewNoteArgs', 'GetReviewNoteArgsDict']]]] = None,
                      principal_profile: Optional[pulumi.Input[Optional[Union['GetReviewPrincipalProfileArgs', 'GetReviewPrincipalProfileArgsDict']]]] = None,
                      reviewer_profile: Optional[pulumi.Input[Optional[Union['GetReviewReviewerProfileArgs', 'GetReviewReviewerProfileArgsDict']]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetReviewResult]:
    """
    Get the reviews belonging to a campaign

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_review()
    ```

    ## Required:

    - `email` (String) The Okta user's email address.
    - `id` (String) The Okta user id.
    - `status` (String) The status of the principal's profile. Enum: `INACTIVE`, `ACTIVE`.

    ## Optional:

    - `first_name` (String) The Okta user's first name.
    - `lastName` (String) The Okta user's last name
    - `login` (String) The Okta user's login


    :param _builtins.str id: The ID of  review.
    :param Union['GetReviewPrincipalProfileArgs', 'GetReviewPrincipalProfileArgsDict'] principal_profile: A limited set of properties from the user profile who created the review.
    """
    __args__ = dict()
    __args__['allReviewerLevels'] = all_reviewer_levels
    __args__['entitlementBundle'] = entitlement_bundle
    __args__['entitlementValue'] = entitlement_value
    __args__['id'] = id
    __args__['links'] = links
    __args__['note'] = note
    __args__['principalProfile'] = principal_profile
    __args__['reviewerProfile'] = reviewer_profile
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getReview:getReview', __args__, opts=opts, typ=GetReviewResult)
    return __ret__.apply(lambda __response__: GetReviewResult(
        all_reviewer_levels=pulumi.get(__response__, 'all_reviewer_levels'),
        campaign_id=pulumi.get(__response__, 'campaign_id'),
        created=pulumi.get(__response__, 'created'),
        created_by=pulumi.get(__response__, 'created_by'),
        current_reviewer_level=pulumi.get(__response__, 'current_reviewer_level'),
        decided=pulumi.get(__response__, 'decided'),
        decision=pulumi.get(__response__, 'decision'),
        entitlement_bundle=pulumi.get(__response__, 'entitlement_bundle'),
        entitlement_value=pulumi.get(__response__, 'entitlement_value'),
        id=pulumi.get(__response__, 'id'),
        last_updated=pulumi.get(__response__, 'last_updated'),
        last_updated_by=pulumi.get(__response__, 'last_updated_by'),
        links=pulumi.get(__response__, 'links'),
        note=pulumi.get(__response__, 'note'),
        principal_profile=pulumi.get(__response__, 'principal_profile'),
        remediation_status=pulumi.get(__response__, 'remediation_status'),
        resource_id=pulumi.get(__response__, 'resource_id'),
        reviewer_profile=pulumi.get(__response__, 'reviewer_profile'),
        reviewer_type=pulumi.get(__response__, 'reviewer_type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FeatureArgs', 'Feature']

@pulumi.input_type
class FeatureArgs:
    def __init__(__self__, *,
                 feature_id: pulumi.Input[_builtins.str],
                 life_cycle: Optional[pulumi.Input[_builtins.str]] = None,
                 mode: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a Feature resource.
        :param pulumi.Input[_builtins.str] feature_id: Okta API for feature only reads and updates therefore the okta*feature resource needs to act as a quasi data source. Do this by setting feature*id
        :param pulumi.Input[_builtins.str] life_cycle: Whether to `ENABLE` or `DISABLE` the feature
        :param pulumi.Input[_builtins.bool] mode: Indicates if you want to force enable or disable a feature. Value is `true` meaning force
        """
        pulumi.set(__self__, "feature_id", feature_id)
        if life_cycle is not None:
            pulumi.set(__self__, "life_cycle", life_cycle)
        if mode is not None:
            pulumi.set(__self__, "mode", mode)

    @_builtins.property
    @pulumi.getter(name="featureId")
    def feature_id(self) -> pulumi.Input[_builtins.str]:
        """
        Okta API for feature only reads and updates therefore the okta*feature resource needs to act as a quasi data source. Do this by setting feature*id
        """
        return pulumi.get(self, "feature_id")

    @feature_id.setter
    def feature_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "feature_id", value)

    @_builtins.property
    @pulumi.getter(name="lifeCycle")
    def life_cycle(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Whether to `ENABLE` or `DISABLE` the feature
        """
        return pulumi.get(self, "life_cycle")

    @life_cycle.setter
    def life_cycle(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "life_cycle", value)

    @_builtins.property
    @pulumi.getter
    def mode(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if you want to force enable or disable a feature. Value is `true` meaning force
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mode", value)


@pulumi.input_type
class _FeatureState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 feature_id: Optional[pulumi.Input[_builtins.str]] = None,
                 life_cycle: Optional[pulumi.Input[_builtins.str]] = None,
                 mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 stage: Optional[pulumi.Input['FeatureStageArgs']] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering Feature resources.
        :param pulumi.Input[_builtins.str] description: Name of the feature.
        :param pulumi.Input[_builtins.str] feature_id: Okta API for feature only reads and updates therefore the okta*feature resource needs to act as a quasi data source. Do this by setting feature*id
        :param pulumi.Input[_builtins.str] life_cycle: Whether to `ENABLE` or `DISABLE` the feature
        :param pulumi.Input[_builtins.bool] mode: Indicates if you want to force enable or disable a feature. Value is `true` meaning force
        :param pulumi.Input[_builtins.str] name: Name of the feature.
        :param pulumi.Input['FeatureStageArgs'] stage: Current release cycle stage of a feature.
        :param pulumi.Input[_builtins.str] status: The feature status.
        :param pulumi.Input[_builtins.str] type: Type of feature.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if feature_id is not None:
            pulumi.set(__self__, "feature_id", feature_id)
        if life_cycle is not None:
            pulumi.set(__self__, "life_cycle", life_cycle)
        if mode is not None:
            pulumi.set(__self__, "mode", mode)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if stage is not None:
            pulumi.set(__self__, "stage", stage)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the feature.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="featureId")
    def feature_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Okta API for feature only reads and updates therefore the okta*feature resource needs to act as a quasi data source. Do this by setting feature*id
        """
        return pulumi.get(self, "feature_id")

    @feature_id.setter
    def feature_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "feature_id", value)

    @_builtins.property
    @pulumi.getter(name="lifeCycle")
    def life_cycle(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Whether to `ENABLE` or `DISABLE` the feature
        """
        return pulumi.get(self, "life_cycle")

    @life_cycle.setter
    def life_cycle(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "life_cycle", value)

    @_builtins.property
    @pulumi.getter
    def mode(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Indicates if you want to force enable or disable a feature. Value is `true` meaning force
        """
        return pulumi.get(self, "mode")

    @mode.setter
    def mode(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "mode", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the feature.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def stage(self) -> Optional[pulumi.Input['FeatureStageArgs']]:
        """
        Current release cycle stage of a feature.
        """
        return pulumi.get(self, "stage")

    @stage.setter
    def stage(self, value: Optional[pulumi.Input['FeatureStageArgs']]):
        pulumi.set(self, "stage", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The feature status.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of feature.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("okta:index/feature:Feature")
class Feature(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 feature_id: Optional[pulumi.Input[_builtins.str]] = None,
                 life_cycle: Optional[pulumi.Input[_builtins.str]] = None,
                 mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        Manages brand. This resource allows you to toggle an Okta Feature.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.get_features(label="Android Device Trust")
        test = okta.Feature("test", feature_id=example.features[0].id)
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/feature:Feature example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] feature_id: Okta API for feature only reads and updates therefore the okta*feature resource needs to act as a quasi data source. Do this by setting feature*id
        :param pulumi.Input[_builtins.str] life_cycle: Whether to `ENABLE` or `DISABLE` the feature
        :param pulumi.Input[_builtins.bool] mode: Indicates if you want to force enable or disable a feature. Value is `true` meaning force
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FeatureArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages brand. This resource allows you to toggle an Okta Feature.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.get_features(label="Android Device Trust")
        test = okta.Feature("test", feature_id=example.features[0].id)
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/feature:Feature example <id>
        ```

        :param str resource_name: The name of the resource.
        :param FeatureArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FeatureArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 feature_id: Optional[pulumi.Input[_builtins.str]] = None,
                 life_cycle: Optional[pulumi.Input[_builtins.str]] = None,
                 mode: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FeatureArgs.__new__(FeatureArgs)

            if feature_id is None and not opts.urn:
                raise TypeError("Missing required property 'feature_id'")
            __props__.__dict__["feature_id"] = feature_id
            __props__.__dict__["life_cycle"] = life_cycle
            __props__.__dict__["mode"] = mode
            __props__.__dict__["description"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["stage"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["type"] = None
        super(Feature, __self__).__init__(
            'okta:index/feature:Feature',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            feature_id: Optional[pulumi.Input[_builtins.str]] = None,
            life_cycle: Optional[pulumi.Input[_builtins.str]] = None,
            mode: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            stage: Optional[pulumi.Input[Union['FeatureStageArgs', 'FeatureStageArgsDict']]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'Feature':
        """
        Get an existing Feature resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Name of the feature.
        :param pulumi.Input[_builtins.str] feature_id: Okta API for feature only reads and updates therefore the okta*feature resource needs to act as a quasi data source. Do this by setting feature*id
        :param pulumi.Input[_builtins.str] life_cycle: Whether to `ENABLE` or `DISABLE` the feature
        :param pulumi.Input[_builtins.bool] mode: Indicates if you want to force enable or disable a feature. Value is `true` meaning force
        :param pulumi.Input[_builtins.str] name: Name of the feature.
        :param pulumi.Input[Union['FeatureStageArgs', 'FeatureStageArgsDict']] stage: Current release cycle stage of a feature.
        :param pulumi.Input[_builtins.str] status: The feature status.
        :param pulumi.Input[_builtins.str] type: Type of feature.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FeatureState.__new__(_FeatureState)

        __props__.__dict__["description"] = description
        __props__.__dict__["feature_id"] = feature_id
        __props__.__dict__["life_cycle"] = life_cycle
        __props__.__dict__["mode"] = mode
        __props__.__dict__["name"] = name
        __props__.__dict__["stage"] = stage
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        return Feature(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the feature.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="featureId")
    def feature_id(self) -> pulumi.Output[_builtins.str]:
        """
        Okta API for feature only reads and updates therefore the okta*feature resource needs to act as a quasi data source. Do this by setting feature*id
        """
        return pulumi.get(self, "feature_id")

    @_builtins.property
    @pulumi.getter(name="lifeCycle")
    def life_cycle(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Whether to `ENABLE` or `DISABLE` the feature
        """
        return pulumi.get(self, "life_cycle")

    @_builtins.property
    @pulumi.getter
    def mode(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Indicates if you want to force enable or disable a feature. Value is `true` meaning force
        """
        return pulumi.get(self, "mode")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the feature.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def stage(self) -> pulumi.Output['outputs.FeatureStage']:
        """
        Current release cycle stage of a feature.
        """
        return pulumi.get(self, "stage")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        The feature status.
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of feature.
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetCatalogEntryDefaultResult',
    'AwaitableGetCatalogEntryDefaultResult',
    'get_catalog_entry_default',
    'get_catalog_entry_default_output',
]

@pulumi.output_type
class GetCatalogEntryDefaultResult:
    """
    A collection of values returned by getCatalogEntryDefault.
    """
    def __init__(__self__, counts=None, description=None, entry_id=None, id=None, label=None, links=None, name=None, parent=None, requestable=None):
        if counts and not isinstance(counts, dict):
            raise TypeError("Expected argument 'counts' to be a dict")
        pulumi.set(__self__, "counts", counts)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if entry_id and not isinstance(entry_id, str):
            raise TypeError("Expected argument 'entry_id' to be a str")
        pulumi.set(__self__, "entry_id", entry_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if label and not isinstance(label, str):
            raise TypeError("Expected argument 'label' to be a str")
        pulumi.set(__self__, "label", label)
        if links and not isinstance(links, dict):
            raise TypeError("Expected argument 'links' to be a dict")
        pulumi.set(__self__, "links", links)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if parent and not isinstance(parent, str):
            raise TypeError("Expected argument 'parent' to be a str")
        pulumi.set(__self__, "parent", parent)
        if requestable and not isinstance(requestable, bool):
            raise TypeError("Expected argument 'requestable' to be a bool")
        pulumi.set(__self__, "requestable", requestable)

    @_builtins.property
    @pulumi.getter
    def counts(self) -> Optional['outputs.GetCatalogEntryDefaultCountsResult']:
        return pulumi.get(self, "counts")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the catalog entry.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="entryId")
    def entry_id(self) -> _builtins.str:
        """
        TThe ID of the catalog entry.
        """
        return pulumi.get(self, "entry_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Unique identifier for the entry.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def label(self) -> _builtins.str:
        """
        Label of the entry. Enum: `Application`, `Resource Collection`.
        """
        return pulumi.get(self, "label")

    @_builtins.property
    @pulumi.getter
    def links(self) -> Optional['outputs.GetCatalogEntryDefaultLinksResult']:
        return pulumi.get(self, "links")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the catalog entry.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def parent(self) -> _builtins.str:
        """
        Parent of the catalog entry.
        """
        return pulumi.get(self, "parent")

    @_builtins.property
    @pulumi.getter
    def requestable(self) -> _builtins.bool:
        """
        Is the resource requestable.
        """
        return pulumi.get(self, "requestable")


class AwaitableGetCatalogEntryDefaultResult(GetCatalogEntryDefaultResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCatalogEntryDefaultResult(
            counts=self.counts,
            description=self.description,
            entry_id=self.entry_id,
            id=self.id,
            label=self.label,
            links=self.links,
            name=self.name,
            parent=self.parent,
            requestable=self.requestable)


def get_catalog_entry_default(counts: Optional[Union['GetCatalogEntryDefaultCountsArgs', 'GetCatalogEntryDefaultCountsArgsDict']] = None,
                              entry_id: Optional[_builtins.str] = None,
                              links: Optional[Union['GetCatalogEntryDefaultLinksArgs', 'GetCatalogEntryDefaultLinksArgsDict']] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCatalogEntryDefaultResult:
    """
    Retrieves a catalog entry.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_catalog_entry_user_access_request_fields()
    ```


    :param _builtins.str entry_id: TThe ID of the catalog entry.
    """
    __args__ = dict()
    __args__['counts'] = counts
    __args__['entryId'] = entry_id
    __args__['links'] = links
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('okta:index/getCatalogEntryDefault:getCatalogEntryDefault', __args__, opts=opts, typ=GetCatalogEntryDefaultResult).value

    return AwaitableGetCatalogEntryDefaultResult(
        counts=pulumi.get(__ret__, 'counts'),
        description=pulumi.get(__ret__, 'description'),
        entry_id=pulumi.get(__ret__, 'entry_id'),
        id=pulumi.get(__ret__, 'id'),
        label=pulumi.get(__ret__, 'label'),
        links=pulumi.get(__ret__, 'links'),
        name=pulumi.get(__ret__, 'name'),
        parent=pulumi.get(__ret__, 'parent'),
        requestable=pulumi.get(__ret__, 'requestable'))
def get_catalog_entry_default_output(counts: Optional[pulumi.Input[Optional[Union['GetCatalogEntryDefaultCountsArgs', 'GetCatalogEntryDefaultCountsArgsDict']]]] = None,
                                     entry_id: Optional[pulumi.Input[_builtins.str]] = None,
                                     links: Optional[pulumi.Input[Optional[Union['GetCatalogEntryDefaultLinksArgs', 'GetCatalogEntryDefaultLinksArgsDict']]]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCatalogEntryDefaultResult]:
    """
    Retrieves a catalog entry.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_okta as okta

    test = okta.get_catalog_entry_user_access_request_fields()
    ```


    :param _builtins.str entry_id: TThe ID of the catalog entry.
    """
    __args__ = dict()
    __args__['counts'] = counts
    __args__['entryId'] = entry_id
    __args__['links'] = links
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('okta:index/getCatalogEntryDefault:getCatalogEntryDefault', __args__, opts=opts, typ=GetCatalogEntryDefaultResult)
    return __ret__.apply(lambda __response__: GetCatalogEntryDefaultResult(
        counts=pulumi.get(__response__, 'counts'),
        description=pulumi.get(__response__, 'description'),
        entry_id=pulumi.get(__response__, 'entry_id'),
        id=pulumi.get(__response__, 'id'),
        label=pulumi.get(__response__, 'label'),
        links=pulumi.get(__response__, 'links'),
        name=pulumi.get(__response__, 'name'),
        parent=pulumi.get(__response__, 'parent'),
        requestable=pulumi.get(__response__, 'requestable')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RateLimitingArgs', 'RateLimiting']

@pulumi.input_type
class RateLimitingArgs:
    def __init__(__self__, *,
                 default_mode: pulumi.Input[_builtins.str],
                 use_case_mode_overrides: Optional[pulumi.Input['RateLimitingUseCaseModeOverridesArgs']] = None):
        """
        The set of arguments for constructing a RateLimiting resource.
        :param pulumi.Input['RateLimitingUseCaseModeOverridesArgs'] use_case_mode_overrides: A map of Per-Client Rate Limit Use Case to the applicable PerClientRateLimitMode.Overrides the defaultMode property for the specified use cases.
        """
        pulumi.set(__self__, "default_mode", default_mode)
        if use_case_mode_overrides is not None:
            pulumi.set(__self__, "use_case_mode_overrides", use_case_mode_overrides)

    @_builtins.property
    @pulumi.getter(name="defaultMode")
    def default_mode(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "default_mode")

    @default_mode.setter
    def default_mode(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "default_mode", value)

    @_builtins.property
    @pulumi.getter(name="useCaseModeOverrides")
    def use_case_mode_overrides(self) -> Optional[pulumi.Input['RateLimitingUseCaseModeOverridesArgs']]:
        """
        A map of Per-Client Rate Limit Use Case to the applicable PerClientRateLimitMode.Overrides the defaultMode property for the specified use cases.
        """
        return pulumi.get(self, "use_case_mode_overrides")

    @use_case_mode_overrides.setter
    def use_case_mode_overrides(self, value: Optional[pulumi.Input['RateLimitingUseCaseModeOverridesArgs']]):
        pulumi.set(self, "use_case_mode_overrides", value)


@pulumi.input_type
class _RateLimitingState:
    def __init__(__self__, *,
                 default_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 use_case_mode_overrides: Optional[pulumi.Input['RateLimitingUseCaseModeOverridesArgs']] = None):
        """
        Input properties used for looking up and filtering RateLimiting resources.
        :param pulumi.Input['RateLimitingUseCaseModeOverridesArgs'] use_case_mode_overrides: A map of Per-Client Rate Limit Use Case to the applicable PerClientRateLimitMode.Overrides the defaultMode property for the specified use cases.
        """
        if default_mode is not None:
            pulumi.set(__self__, "default_mode", default_mode)
        if use_case_mode_overrides is not None:
            pulumi.set(__self__, "use_case_mode_overrides", use_case_mode_overrides)

    @_builtins.property
    @pulumi.getter(name="defaultMode")
    def default_mode(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "default_mode")

    @default_mode.setter
    def default_mode(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "default_mode", value)

    @_builtins.property
    @pulumi.getter(name="useCaseModeOverrides")
    def use_case_mode_overrides(self) -> Optional[pulumi.Input['RateLimitingUseCaseModeOverridesArgs']]:
        """
        A map of Per-Client Rate Limit Use Case to the applicable PerClientRateLimitMode.Overrides the defaultMode property for the specified use cases.
        """
        return pulumi.get(self, "use_case_mode_overrides")

    @use_case_mode_overrides.setter
    def use_case_mode_overrides(self, value: Optional[pulumi.Input['RateLimitingUseCaseModeOverridesArgs']]):
        pulumi.set(self, "use_case_mode_overrides", value)


@pulumi.type_token("okta:index/rateLimiting:RateLimiting")
class RateLimiting(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 use_case_mode_overrides: Optional[pulumi.Input[Union['RateLimitingUseCaseModeOverridesArgs', 'RateLimitingUseCaseModeOverridesArgsDict']]] = None,
                 __props__=None):
        """
        Manages rate limiting.
        This resource allows you to configure the client-based rate limit and rate limiting communications settings.
        > **WARNING:** This resource is deprecated and will be removed in a future release. A new resource to manage rate limiting settings will be implemented in the future.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.RateLimiting("example",
            login="ENFORCE",
            authorize="ENFORCE",
            communications_enabled=True)
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/rateLimiting:RateLimiting example .
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['RateLimitingUseCaseModeOverridesArgs', 'RateLimitingUseCaseModeOverridesArgsDict']] use_case_mode_overrides: A map of Per-Client Rate Limit Use Case to the applicable PerClientRateLimitMode.Overrides the defaultMode property for the specified use cases.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RateLimitingArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages rate limiting.
        This resource allows you to configure the client-based rate limit and rate limiting communications settings.
        > **WARNING:** This resource is deprecated and will be removed in a future release. A new resource to manage rate limiting settings will be implemented in the future.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_okta as okta

        example = okta.RateLimiting("example",
            login="ENFORCE",
            authorize="ENFORCE",
            communications_enabled=True)
        ```

        ## Import

        ```sh
        $ pulumi import okta:index/rateLimiting:RateLimiting example .
        ```

        :param str resource_name: The name of the resource.
        :param RateLimitingArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RateLimitingArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_mode: Optional[pulumi.Input[_builtins.str]] = None,
                 use_case_mode_overrides: Optional[pulumi.Input[Union['RateLimitingUseCaseModeOverridesArgs', 'RateLimitingUseCaseModeOverridesArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RateLimitingArgs.__new__(RateLimitingArgs)

            if default_mode is None and not opts.urn:
                raise TypeError("Missing required property 'default_mode'")
            __props__.__dict__["default_mode"] = default_mode
            __props__.__dict__["use_case_mode_overrides"] = use_case_mode_overrides
        super(RateLimiting, __self__).__init__(
            'okta:index/rateLimiting:RateLimiting',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            default_mode: Optional[pulumi.Input[_builtins.str]] = None,
            use_case_mode_overrides: Optional[pulumi.Input[Union['RateLimitingUseCaseModeOverridesArgs', 'RateLimitingUseCaseModeOverridesArgsDict']]] = None) -> 'RateLimiting':
        """
        Get an existing RateLimiting resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Union['RateLimitingUseCaseModeOverridesArgs', 'RateLimitingUseCaseModeOverridesArgsDict']] use_case_mode_overrides: A map of Per-Client Rate Limit Use Case to the applicable PerClientRateLimitMode.Overrides the defaultMode property for the specified use cases.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RateLimitingState.__new__(_RateLimitingState)

        __props__.__dict__["default_mode"] = default_mode
        __props__.__dict__["use_case_mode_overrides"] = use_case_mode_overrides
        return RateLimiting(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="defaultMode")
    def default_mode(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "default_mode")

    @_builtins.property
    @pulumi.getter(name="useCaseModeOverrides")
    def use_case_mode_overrides(self) -> pulumi.Output[Optional['outputs.RateLimitingUseCaseModeOverrides']]:
        """
        A map of Per-Client Rate Limit Use Case to the applicable PerClientRateLimitMode.Overrides the defaultMode property for the specified use cases.
        """
        return pulumi.get(self, "use_case_mode_overrides")

